summaryrefslogtreecommitdiff
path: root/svx/source/fmcomp/fmgridcl.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/source/fmcomp/fmgridcl.cxx')
-rw-r--r--svx/source/fmcomp/fmgridcl.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index 8d88f7e4a5a8..def9fa650bd2 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -1808,7 +1808,7 @@ Sequence< Any> FmGridControl::getSelectionBookmarks()
// The next problem caused by the same behaviuor (SeekCursor causes a propertyChanged) : when adjusting rows we implicitly
// change our selection. So a "FirstSelected(); SeekCursor(); NextSelected();" may produce unpredictable results.
// That's why we _first_ collect the indicies of the selected rows and _then_ their bookmarks.
long nIdx = FirstSelectedRow();
while (nIdx >= 0)
{
@@ -1816,7 +1816,7 @@ Sequence< Any> FmGridControl::getSelectionBookmarks()
pBookmarks[i++] <<= (sal_Int32)nIdx;
nIdx = NextSelectedRow();
}
- DBG_ASSERT(i == nSelectedRows, "FmGridControl::DeleteSelectedRows : could not collect the row indicies !");
+ DBG_ASSERT(i == nSelectedRows, "FmGridControl::DeleteSelectedRows : could not collect the row indices !");
for (i=0; i<nSelectedRows; ++i)
{
@@ -1808,7 +1808,7 @@ Sequence< Any> FmGridControl::getSelectionBookmarks()
// The next problem caused by the same behaviuor (SeekCursor causes a propertyChanged) : when adjusting rows we implicitly
// change our selection. So a "FirstSelected(); SeekCursor(); NextSelected();" may produce unpredictable results.
- // That's why we _first_ collect the indicies of the selected rows and _then_ their bookmarks.
+ // That's why we _first_ collect the indices of the selected rows and _then_ their bookmarks.
long nIdx = FirstSelectedRow();
while (nIdx >= 0)